==> 0.0.0.tar.gz: test/contextdart_test.dart <==
import 'dart:async';

import 'package:contextdart/contextdart.dart';
import "package:test/test.dart";

void main() {
  test("#value", () {
    var ctx = Context.background();
    ctx = Context.withValue(ctx, "1", 11);
    ctx = Context.withValue(ctx, "2", 22);

    expect(ctx.value<int>("2"), 22);
    expect(ctx.value<int>("1"), 11);
    expect(ctx.value<int>("x"), null);
  });

  test("#cancel", () async {
    var ctx = Context.background();
    var cctx = Context.withCancel(ctx);

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var cancel = Exception("cancel");

    cctx.cancel(cancel);

    var ret = await jobs;
    expect(ret, cancel);
  });

  test("#withTimeout", () async {
    var ctx = Context.background();
    var cctx = Context.withTimeout(ctx, const Duration(milliseconds: 500));

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var ret = await jobs;
    expect(ret, exceptionDeadlineExceeded);
  });

  test("#withDeadline", () async {
    var ctx = Context.background();
    var cctx = Context.withDeadline(
      ctx,
      DateTime.now().add(const Duration(milliseconds: 500)),
    );

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var ret = await jobs;
    expect(ret, exceptionDeadlineExceeded);
  });

  test("#withCancel should cancel children if exists", () async {
    doChildJob(Context parent) async {
      var childCCtx = Context.withCancel(parent);

      return await Future.any([
        childCCtx.done()!.first,
        Stream.periodic(const Duration(seconds: 1))
            .map((e) => Exception("bomb!"))
            .first,
      ]);
    }

    var ctx = Context.background();
    var parentCCtx = Context.withCancel(ctx);

    var job1 = doChildJob(parentCCtx);
    var job2 = doChildJob(parentCCtx);

    var cancel = Exception("parent cancel");
    parentCCtx.cancel(cancel);

    expect(await job1, cancel);
    expect(await job2, cancel);

    var jobAfterCancel = doChildJob(parentCCtx);
    expect(await jobAfterCancel, cancel);
  });
}

==> 0.0.2.tar.gz: test/contextdart_test.dart <==
import 'dart:async';

import 'package:contextdart/contextdart.dart';
import "package:test/test.dart";

class Int1 {}

class Int2 {}

void main() {
  test("#value", () {
    var ctx = Context.background();
    ctx = Context.withValue(ctx, "1", 11);
    ctx = Context.withValue(ctx, "2", 22);

    expect(ctx.value("2"), 22);
    expect(ctx.value("1"), 11);
    expect(ctx.value("x"), null);
  });

  test("#value type match only", () {
    var ctx = Context.background();
    var int1 = Int1();
    var int2 = Int2();
    var int11 = Int1();

    ctx = Context.withTypedValue(ctx, int1);
    ctx = Context.withTypedValue(ctx, int2);
    ctx = Context.withTypedValue(ctx, int11);

    expect(ctx.value<Int1>(), int11);
    expect(ctx.value<Int2>(), int2);
  });

  test("#cancel", () async {
    var ctx = Context.background();
    var cctx = Context.withCancel(ctx);

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var cancel = Exception("cancel");

    cctx.cancel(cancel);

    var ret = await jobs;
    expect(ret, cancel);
  });

  test("#withTimeout", () async {
    var ctx = Context.background();
    var cctx = Context.withTimeout(ctx, const Duration(milliseconds: 500));

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var ret = await jobs;
    expect(ret, exceptionDeadlineExceeded);
  });

  test("#withDeadline", () async {
    var ctx = Context.background();
    var cctx = Context.withDeadline(
      ctx,
      DateTime.now().add(const Duration(milliseconds: 500)),
    );

    var jobs = Future.any([
      cctx.done()!.first,
      Stream.periodic(const Duration(seconds: 1))
          .map((e) => Exception("bomb!"))
          .first,
    ]);

    var ret = await jobs;
    expect(ret, exceptionDeadlineExceeded);
  });

  test("#withCancel should cancel children if exists", () async {
    doChildJob(Context parent) async {
      var childCCtx = Context.withCancel(parent);

      return await Future.any([
        childCCtx.done()!.first,
        Stream.periodic(const Duration(seconds: 1))
            .map((e) => Exception("bomb!"))
            .first,
      ]);
    }

    var ctx = Context.background();
    var parentCCtx = Context.withCancel(ctx);

    var job1 = doChildJob(parentCCtx);
    var job2 = doChildJob(parentCCtx);

    var cancel = Exception("parent cancel");
    parentCCtx.cancel(cancel);

    expect(await job1, cancel);
    expect(await job2, cancel);

    var jobAfterCancel = doChildJob(parentCCtx);
    expect(await jobAfterCancel, cancel);
  });
}
